==> danse-2.2.7.tar.gz: danse/modules/webhook/src/Payload.php <==
<?php

namespace Drupal\danse_webhook;

use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\danse\Entity\Event;
use Drupal\node\Entity\Node;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;

/**
 * Class Payload.
 *
 * @package Drupal\danse_webhook
 */
final class Payload extends PayloadBase {

  /**
   * @var string
   */
  protected $extId;

  /**
   * @var array
   */
  protected $recipients;

  /**
   * @var string
   */
  protected $label;

  /**
   * @var string
   */
  protected $message;

  /**
   * Content constructor.
   *
   * @param string $extId
   */
  public function __construct($extId) {
    $this->extId = $extId;
  }

  /**
   * {@inheritdoc}
   */
  public function label(Event $event): string {
    return $this->label;
  }

  /**
   * @param string $recipient
   *
   * @return \Drupal\danse_webhook\Payload
   */
  public function addRecipient($recipient): Payload {
    $this->recipients[] = $recipient;
    return $this;
  }

  /**
   * @param string $label
   *
   * @return \Drupal\danse_webhook\Payload
   */
  public function setLabel($label): Payload {
    $this->label = $label;
    return $this;
  }

  /**
   * @param string $message
   *
   * @return \Drupal\danse_webhook\Payload
   */
  public function setMessage($message): Payload {
    $this->message = $message;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', ['webhook', $this->extId]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'extid' => $this->extId,
      'recipients' => $this->recipients ?? [],
      'label' => $this->label,
      'message' => $this->message,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): ?PayloadInterface {
    $item = new Payload($payload['extid']);
    foreach ($payload['recipients'] as $recipient) {
      $item->addRecipient($recipient);
    }
    $item
      ->setLabel($payload['label'])
      ->setMessage($payload['message']);
    return $item;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /** @var \Drupal\node\NodeInterface $entity */
    $entity = Node::create([
      'title' => $this->label,
      'body' => $this->message,
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess($uid): bool {
    if (empty($this->recipients)) {
      return TRUE;
    }

    try {
      $storage = Drupal::entityTypeManager()->getStorage('user');
      foreach ($this->recipients as $recipient) {
        $users = $storage->getQuery('OR')
          ->condition('name', $recipient)
          ->condition('mail', $recipient)
          ->execute();
        if (!empty($users)) {
          return TRUE;
        }
      }
    }
    catch (InvalidPluginDefinitionException $e) {
      // TODO: Log this exception.
    }
    catch (PluginNotFoundException $e) {
      // TODO: Log this exception.
    }
    return FALSE;
  }

}

==> danse-2.2.10.tar.gz: danse/modules/webhook/src/Payload.php <==
<?php

namespace Drupal\danse_webhook;

use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\node\Entity\Node;
use Drupal\danse\Entity\EventInterface;
use Drupal\danse\PayloadBase;
use Drupal\danse\PayloadInterface;

/**
 * The webhook payload class.
 *
 * @package Drupal\danse_webhook
 */
final class Payload extends PayloadBase {

  /**
   * The external ID.
   *
   * @var string
   */
  protected string $extId;

  /**
   * The list of recipients.
   *
   * @var array
   */
  protected array $recipients;

  /**
   * The label.
   *
   * @var string
   */
  protected string $label;

  /**
   * The message.
   *
   * @var string
   */
  protected string $message;

  /**
   * Webhook payload constructor.
   *
   * @param string $extId
   *   The external ID.
   */
  public function __construct(string $extId) {
    $this->extId = $extId;
  }

  /**
   * {@inheritdoc}
   */
  public function label(EventInterface $event): string {
    return $this->label;
  }

  /**
   * Adds a recipient.
   *
   * @param string $recipient
   *   The recipient.
   *
   * @return \Drupal\danse_webhook\Payload
   *   Self.
   */
  public function addRecipient(string $recipient): Payload {
    $this->recipients[] = $recipient;
    return $this;
  }

  /**
   * Sets the label.
   *
   * @param string $label
   *   The label.
   *
   * @return \Drupal\danse_webhook\Payload
   *   Self.
   */
  public function setLabel(string $label): Payload {
    $this->label = $label;
    return $this;
  }

  /**
   * Set the message.
   *
   * @param string $message
   *   The message.
   *
   * @return \Drupal\danse_webhook\Payload
   *   Self.
   */
  public function setMessage(string $message): Payload {
    $this->message = $message;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getEventReference(): string {
    return implode('-', ['webhook', $this->extId]);
  }

  /**
   * {@inheritdoc}
   */
  public function getSubscriptionReferences(EventInterface $event): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function prepareArray(): array {
    return [
      'extid' => $this->extId,
      'recipients' => $this->recipients ?? [],
      'label' => $this->label,
      'message' => $this->message,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function createFromArray(array $payload): ?PayloadInterface {
    $item = new Payload($payload['extid']);
    foreach ($payload['recipients'] as $recipient) {
      $item->addRecipient($recipient);
    }
    $item
      ->setLabel($payload['label'])
      ->setMessage($payload['message']);
    return $item;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntity(): ContentEntityInterface {
    /**
     * @var \Drupal\node\NodeInterface $entity
     */
    $entity = Node::create([
      'title' => $this->label,
      'body' => $this->message,
    ]);
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function hasAccess(int $uid): bool {
    if (empty($this->recipients)) {
      return TRUE;
    }

    try {
      $storage = \Drupal::entityTypeManager()->getStorage('user');
      foreach ($this->recipients as $recipient) {
        $users = $storage->getQuery('OR')
          ->condition('name', $recipient)
          ->condition('mail', $recipient)
          ->execute();
        if (!empty($users)) {
          return TRUE;
        }
      }
    }
    catch (InvalidPluginDefinitionException | PluginNotFoundException $e) {
      // @todo Log this exception.
    }
    return FALSE;
  }

}
